@@ -3,29 +3,17 @@ mod graph;
 mod inspect;
 mod model_info;
 pub mod run;
+mod unstable;
 mod version;
 
+pub use crate::{
+    graph::Graph, inspect::Inspect, model_info::ModelInfo, run::Run,
+    build::Build, version::Version, unstable::Unstable,
+};
+
 use codespan_reporting::term::termcolor;
 use env_logger::WriteStyle;
 
-pub use crate::{
-    graph::Graph, model_info::ModelInfo, inspect::Inspect, run::Run,
-    build::Build, version::Version,
-};
-
-pub const DEFAULT_RUST_LOG: &str = concat!(
-    "info,",
-    "hotg_rune_cli=debug,",
-    "hotg_rune_codegen=debug,",
-    "hotg_rune_core=debug,",
-    "hotg_rune_runtime=debug,",
-    "hotg_rune_syntax=debug,",
-    "hotg_rune_wasmer_runtime=debug,",
-    "hotg_rune_wasm3_runtime=debug,",
-    "hotg_runicos_base_runtime=debug,",
-    "regalloc=warn,",
-);
-
 #[derive(
     Debug, Copy, Clone, PartialEq, strum::EnumVariantNames, strum::EnumString,
 )]
